diff Plugins/Include/orthanc/OrthancCPlugin.h @ 4024:1d2b31fc782f more-changes

new 'changes': JobSubmitted, JobSuccess, JobFailure
author Alain Mazy <alain@mazy.be>
date Tue, 09 Jun 2020 12:20:42 +0200
parents 3b0c555f16a3
children ae7ebd5b0443
line wrap: on
line diff
--- a/Plugins/Include/orthanc/OrthancCPlugin.h	Tue Jun 09 11:54:58 2020 +0200
+++ b/Plugins/Include/orthanc/OrthancCPlugin.h	Tue Jun 09 12:20:42 2020 +0200
@@ -716,7 +716,7 @@
 
 
   /**
    * The supported types of changes that can happen to DICOM resources.
    * @ingroup Callbacks
    **/
   typedef enum
@@ -737,6 +737,9 @@
     OrthancPluginChangeType_UpdatedMetadata = 13,   /*!< Some user-defined metadata has changed for this resource */
     OrthancPluginChangeType_UpdatedPeers = 14,      /*!< The list of Orthanc peers has changed */
     OrthancPluginChangeType_UpdatedModalities = 15, /*!< The list of DICOM modalities has changed */
+    OrthancPluginChangeType_JobSubmitted = 16,      /*!< New Job submitted */
+    OrthancPluginChangeType_JobSuccess = 17,        /*!< A Job has completed successfully */
+    OrthancPluginChangeType_JobFailure = 18,        /*!< A Job has failed */
 
     _OrthancPluginChangeType_INTERNAL = 0x7fffffff
   } OrthancPluginChangeType;
@@ -716,7 +716,7 @@
 
   /**
-   * The supported types of changes that can happen to DICOM resources.
+   * The supported types of changes that can be signaled to the change callback.
    * @ingroup Callbacks
    **/